==> react-lds-8.7.0.tgz: package/es/components/Modal/ModalHeader.js <==
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { IconButton, ButtonIcon } from '../Button';
import { THEMES, getThemeClass } from '../../utils';

var ModalHeader = function ModalHeader(props) {
  var id = props.id,
      onClose = props.onClose,
      theme = props.theme,
      title = props.title,
      tagline = props.tagline;
  var isEmpty = !tagline && !title;
  return React.createElement("header", {
    className: cx.apply(void 0, ['slds-modal__header', {
      'slds-modal__header_empty': isEmpty
    }].concat(_toConsumableArray(getThemeClass(theme))))
  }, onClose && React.createElement(IconButton, {
    className: "slds-modal__close",
    flavor: "inverse",
    onClick: onClose,
    tabIndex: 0
  }, React.createElement(ButtonIcon, {
    sprite: "utility",
    icon: "close",
    size: "large"
  })), title && React.createElement("h2", {
    className: "slds-text-heading_medium slds-hyphenate",
    id: id
  }, title), tagline && React.createElement("p", {
    className: "slds-m-top_x-small"
  }, tagline));
};

ModalHeader.defaultProps = {
  id: null,
  onClose: null,
  title: null,
  tagline: null,
  theme: null
};
ModalHeader.propTypes = process.env.NODE_ENV !== "production" ? {
  id: PropTypes.string,
  onClose: PropTypes.func,
  theme: PropTypes.oneOf(THEMES),
  title: PropTypes.string,
  tagline: PropTypes.oneOfType([PropTypes.string, PropTypes.element])
} : {};
export default ModalHeader;

==> react-lds-9.1.0.tgz: package/es/components/Modal/ModalHeader.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { IconButton, ButtonIcon } from '../Button';
import { THEMES, getThemeClass } from '../../utils';

var ModalHeader = function ModalHeader(props) {
  var id = props.id,
      onClose = props.onClose,
      theme = props.theme,
      title = props.title,
      tagline = props.tagline;
  var isEmpty = !tagline && !title;
  return React.createElement("header", {
    className: cx.apply(void 0, ['slds-modal__header', {
      'slds-modal__header_empty': isEmpty
    }].concat(_toConsumableArray(getThemeClass(theme))))
  }, onClose && React.createElement(IconButton, {
    className: "slds-modal__close",
    flavor: "inverse",
    onClick: onClose,
    tabIndex: 0
  }, React.createElement(ButtonIcon, {
    sprite: "utility",
    icon: "close",
    size: "large"
  })), title && React.createElement("h2", {
    className: "slds-text-heading_medium slds-hyphenate",
    id: id
  }, title), tagline && React.createElement("p", {
    className: "slds-m-top_x-small"
  }, tagline));
};

ModalHeader.defaultProps = {
  id: null,
  onClose: null,
  title: null,
  tagline: null,
  theme: null
};
ModalHeader.propTypes = process.env.NODE_ENV !== "production" ? {
  id: PropTypes.string,
  onClose: PropTypes.func,
  theme: PropTypes.oneOf(THEMES),
  title: PropTypes.string,
  tagline: PropTypes.oneOfType([PropTypes.string, PropTypes.element])
} : {};
export default ModalHeader;
